## 2022/10/26

* add `change` master password


## 2021/08/08

* support py3


## 2018/10/01

* display password entries with id
* add `delete` password
* add manually `add` password


## 2018/05/29

* encrypt ~/.passtk


## 2015/10/31

* add `-m` option to store password with comment


## 2015/07/09

* auto store generated password into ~/.passtk
* add `-u` option to disable stroing password
* add `-p` option to show password in ~/.passtk


## 2013/01/10

The random.sample will chooses a *set of unique* letters.
So if the number is greater than the set's length, will throw an error:
ValueError: sample larger than population


## 2013/01/11

* Fix a bug when level is one
